local E, L, V, P, G = unpack(ElvUI); 
local UF = E:GetModule("UnitFrames")
local EPA = E:GetModule('EPA')

local Order = 0
local function getOrder()
	Order = Order +1
	return Order
end

local function configTable()
	local auraAnchors = {
		TOP = 'TOP',
		BOTTOM = 'BOTTOM',
		LEFT = 'LEFT',
		RIGHT = 'RIGHT',
		CENTER = 'CENTER',
		TOPLEFT = 'TOPLEFT',
		TOPRIGHT = 'TOPRIGHT',
		BOTTOMRIGHT = 'BOTTOMRIGHT',
		BOTTOMLEFT = 'BOTTOMLEFT',
	};

	E.Options.args.epa = {
		order = getOrder(),
		type = 'group',
		childGroups = "tab",
		name = EPA.Title,
		args = {}
	}
	E.Options.args.epa.args.extras = {
		order = getOrder(),
		type = 'group',
		name = '',
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = true,
		args = {
			frequency = {
				order = getOrder(),
				type = "range",
				name = "Refresh Rate",
				desc = "Seconds between status refreshes",
				width = "full",
				get = function () return E.db.epa.cycle_time end,
				set = function (_, v) E.db.epa.cycle_time = v end,
				min = 0.25,
				max = 5,
				step = 0.05,
			},
			first_groups_only = {
				order = getOrder(),
				type = "toggle",
				name = "First Groups Only",
				desc = "Depending on the raid size, checks only the first groups to improve performance",
				get = function () return E.db.epa.first_groups_only end,
				set = function (_, v) E.db.epa.first_groups_only = v; EPA:UpdateNumGroups() end,
			},
			targets_hit = {
				order = getOrder(),
				type = "toggle",
				name = "AoE Icon Numbers",
				desc = "Show the amount of targets you will hit with your AE heal.",
				get = function () return E.db.epa.targets_hit end,
				set = function (_, v) E.db.epa.targets_hit = v end,
			},
		}
	}--[[
	E.Options.args.epa.args.debug = {
		order = getOrder(),
		type = 'group',
		name = 'Test Mode',
		guiInline = true,
		args = {
			one = {
				order = getOrder(),
				type = 'toggle',
				name = 'Debug One',
				get = function () return E.db.epa.debug.one end,
				set = function (_, v) E.db.epa.debug.one = v end,	
				},			
			two = {
				order = getOrder(),
				type = 'toggle',
				name = 'Debug Two (Gain,Lost)',
				get = function () return E.db.epa.debug.two end,
				set = function (_, v) E.db.epa.debug.two = v end,	
				},			
			three = {
				order = getOrder(),
				type = 'toggle',
				name = 'Debug Three (Visib)',
				get = function () return E.db.epa.debug.three end,
				set = function (_, v) E.db.epa.debug.three = v end,	
				},			
			four = {
				order = getOrder(),
				type = 'toggle',
				name = 'Debug Four',
				get = function () return E.db.epa.debug.four end,
				set = function (_, v) E.db.epa.debug.four = v end,	
				},
			test = {
				order = getOrder(),
				type = 'toggle',
				name = 'Test Mode',
				get = function () return E.db.epa.debug.testmode end,
				set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
				},
			}
	}]]

	E.Options.args.epa.args.coh = {
		type = 'group',
		name = 'Circle of Healing',
		order = getOrder(),
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = false,
		args = {
			coh_enable = {
						order = getOrder(),
						type = "toggle",
						name = "Enable",
						desc = "Enable Circle of Healing",
						get = function()
						return E.db.epa.coh.enable
						end,
						set = function(_, v)
							E.db.epa.coh.enable = v
								if not v then
									if EPA.OnStatusDisable then
										EPA:OnStatusDisable("coh")
									end
								end
						end,
			},
			coh_opacity = {
						name = "Opacity",
						desc = "Opacity for Circle of Healing",
						order = getOrder(),
						type = "range",
						min = 0.05,
						max = 1,
						step = 0.05,
						isPercent = true,
						get = function() local color = E.db.epa.coh.color return color.a end,
						set = function(_, a) local color = E.db.epa.coh.color color.a = a or 1 end,
							--func = function() GridStatus:ResetClassColors() end,
						},			
			coh_threshold = {
						order = getOrder(),
						type = "range",
						name = "Heal threshold",
						desc = "Threshold for heal amount",
						softMax = 250000,
						min = 1,
						step = 1,
						width = "full",
						get = function () return E.db.epa.coh.threshold end,
						set = function (_, v) E.db.epa.coh.threshold = v end,
			},
			coh_enable_if_have = {
						order = getOrder(),
						type = "toggle",
						name = "Show only while having the talent",
						desc = "Enable this if you want to hide this status while using a talent spec that does not include Circle of Healing",
						width = "full",
						get = function () return E.db.epa.coh.enable_if_have end,
						set = function (_, v) E.db.epa.coh.enable_if_have = v; EPA:UpdateTalents(); end,
			},
			coh_hidecd = {
						order = getOrder(),
						type = "toggle",
						name = "Hide while on cooldown",
						desc = "Hide status while Circle of Healing is on cooldown",
						width = "full",
						get = function () return E.db.epa.coh.hidecd end,
						set = function (_, arg) E.db.epa.coh.hidecd = arg end,
			},
			iconoptions = {
				order = getOrder(),
				type = 'group',
				name = 'CoH Icon Options',
				guiInline = true,
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['coh'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['coh'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
			},
		}
	}
	E.Options.args.epa.args.poh = {
		type = 'group',
		name = 'Prayer of Healing',
		order = getOrder(),
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = false,
		args = {
			poh_enable = {
						order = getOrder(),
						type = "toggle",
						name = "Enable",
						desc = "Enable Prayer of Healing",
						get = function()
						return E.db.epa.poh.enable
						end,
						set = function(_, v)
							E.db.epa.poh.enable = v
								if not v then
									if EPA.OnStatusDisable then
										EPA:OnStatusDisable("poh")
									end
								end
						end,					
			},
			poh_numtargets = {
						name = "Min Targets",
						desc = "Minimum number to show icon",
						order = getOrder(),
						type = "range",
						min = 1,
						max = 5,
						step = 1,
						get = function() return E.db.epa.poh.numtargets end,
						set = function(_, v) E.db.epa.poh.numtargets = v end,
			},
			poh_opacity = {
						name = "Opacity",
						desc = "Opacity for Prayer of Healing",
						order = getOrder(),
						type = "range",
						min = 0.05,
						max = 1,
						step = 0.05,
						isPercent = true,
						get = function() local color = E.db.epa.poh.color return color.a end,
						set = function(_, a) local color = E.db.epa.poh.color color.a = a or 1 end,
							--func = function() GridStatus:ResetClassColors() end,
			},			
			poh_threshold = {
						order = getOrder(),
						type = "range",
						name = "Heal threshold",
						desc = "Threshold for heal amount",
						softMax = 250000,
						min = 1,
						step = 1,
						width = "full",
						get = function () return E.db.epa.poh.threshold end,
						set = function (_, v) E.db.epa.poh.threshold = v end,
			},
			poh_enablebest = {
						order = getOrder(),
						type = "toggle",
						name = "Always show best target in each group",
						desc = "Shows best target to cast Prayer of Healing on in each group, even if the heal amount is below the threshold (minimum 3 targets)",
						width = "full",
						get = function () return E.db.epa.poh.always_best end,
						set = function (_, v) E.db.epa.poh.always_best = v end,
				},
			poh_SS = {
						order = getOrder(),
						type = "toggle",
						name = "Show best if Spirit Shell if ready",
						desc = "Shows best target to cast PoH on in each group, even if the heal amount is below the threshold (minimum 3 targets) while Spirit Shell is off CD.",
						width = "full",
						get = function () return E.db.epa.poh.SS end,
						set = function (_, v) E.db.epa.poh.SS = v end,
				},
			poh_incomingheals = {
						order = getOrder(),
						type = "toggle",
						name = "Subtract incoming heals",
						desc = "Subtracts incoming heals from the health deficit before making the calculations (your own heals are excluded)",
						width = "full",
						get = function () return E.db.epa.poh.incoming_heals end,
						set = function (_, v) E.db.epa.poh.incoming_heals = v end,
			},
			iconoptions = {
				order = getOrder(),
				type = 'group',
				guiInline = true,
				name = 'PoH Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['poh'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['poh'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,
						},
					},
			},
		}	
	}	
	E.Options.args.epa.args.ch = {
		type = 'group',
		name = 'Chain Heal',
		order = getOrder(),
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = false,
		args = {
			desc = {
					name = "NOTE: Chain Heal is a more intensive search than all the other modules and is disabled by default. Refresh rate recommended to be 1 sec or more.",
					order = getOrder(),
					type = 'description',
					width = "full",
			},
					
			ch_enable = {
						order = getOrder(),
						type = "toggle",
						name = "Enable",
						desc = "Enable Chain Heal",
						get = function()
						return E.db.epa.ch.enable
						end,
						set = function(_, v)
							E.db.epa.ch.enable = v
								if not v then
									if EPA.OnStatusDisable then
										EPA:OnStatusDisable("ch")
									end
								end
						end,					
			},
			ch_opacity = {
						name = "Opacity",
						desc = "Opacity for Chain Heal",
						order = getOrder(),
						type = "range",
						min = 0.05,
						max = 1,
						step = 0.05,
						isPercent = true,
						get = function() local color = E.db.epa.ch.color return color.a end,
						set = function(_, a) local color = E.db.epa.ch.color color.a = a or 1 end,
							--func = function() GridStatus:ResetClassColors() end,
			},			
			ch_threshold = {
						order = getOrder(),
						type = "range",
						name = "Heal threshold",
						desc = "Threshold for heal amount",
						softMax = 250000,
						min = 1,
						step = 1,
						width = "full",
						get = function () return E.db.epa.ch.threshold end,
						set = function (_, v) E.db.epa.ch.threshold = v end,
			},
			--[[ch_minjump = {
						order = getOrder(),
						type = "range",
						name = "Jump threshold",
						desc = "Only consider targets that will result in at least this number of Chain Heal jumps.",
						max = 3,
						min = 1,
						step = 1,
						get = function () return E.db.epa.ch.minjump end,
						set = function (_, v) E.db.epa.ch.minjump = v end,
			},
			ch_maxhealth = {
						order = getOrder(),
						type = "range",
						name = "Health threshold",
						desc = "Only consider targets below this percentage of health.",
						max = 100,
						min = 1,
						step = 1,
						get = function () return E.db.epa.ch.maxhealth end,
						set = function (_, v) E.db.epa.ch.maxhealth = v end,
			},]]
			iconoptions = {
				order = getOrder(),
				type = 'group',
				name = 'CH Icon Options',
				guiInline = true,
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['ch'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['ch'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},
				},
			},
		}	
	}
	E.Options.args.epa.args.hr = {
		type = 'group',
		name = 'Holy Radiance',
		order = getOrder(),
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = false,
		args = {
			hr_enable = {
						order = getOrder(),
						type = "toggle",
						name = "Enable",
						desc = "Enable Holy Radiance",
						get = function()
						return E.db.epa.hr.enable
						end,
						set = function(_, v)
							E.db.epa.hr.enable = v
								if not v then
									if EPA.OnStatusDisable then
										EPA:OnStatusDisable("hr")
									end
								end
						end,					
			},
			hr_numtargets = {
						name = "Min Targets",
						desc = "Minimum number to show icon",
						order = getOrder(),
						type = "range",
						min = 1,
						max = 6,
						step = 1,
						get = function() return E.db.epa.hr.numtargets end,
						set = function(_, v) E.db.epa.hr.numtargets = v end,
			},
			hr_opacity = {
						name = "Opacity",
						desc = "Opacity for Holy Radiance",
						order = getOrder(),
						type = "range",
						min = 0.05,
						max = 1,
						step = 0.05,
						isPercent = true,
						get = function() local color = E.db.epa.hr.color return color.a end,
						set = function(_, a) local color = E.db.epa.hr.color color.a = a or 1 end,
							--func = function() GridStatus:ResetClassColors() end,
			},			
			hr_threshold = {
						order = getOrder(),
						type = "range",
						name = "Heal threshold",
						desc = "Threshold for heal amount",
						softMax = 250000,
						min = 1,
						step = 1,
						width = "full",
						get = function () return E.db.epa.hr.threshold end,
						set = function (_, v) E.db.epa.hr.threshold = v end,
			},
			iconoptions = {
				order = getOrder(),
				type = 'group',
				name = 'HR Icon Options',
				guiInline = true,
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['hr'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['hr'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
			},
		}
	}
	E.Options.args.epa.args.wg = {
		type = 'group',
		name = 'Wild Growth',
		order = getOrder(),
		--get = function(info) return AS:CheckOption(info[#info]) end,
		--set = function(info, value) AS:SetOption(info[#info], value) end,
		guiInline = false,
		args = {
			wg_enable = {
						order = getOrder(),
						type = "toggle",
						name = "Enable",
						desc = "Enable Wild Growth",
						get = function()
						return E.db.epa.wg.enable
						end,
						set = function(_, v)
							E.db.epa.wg.enable = v
								if not v then
									if EPA.OnStatusDisable then
										EPA:OnStatusDisable("wg")
									end
								end
						end,
			},
			wg_opacity = {
						name = "Opacity",
						desc = "Opacity for Wild Growth",
						order = getOrder(),
						type = "range",
						min = 0.05,
						max = 1,
						step = 0.05,
						isPercent = true,
						get = function() local color = E.db.epa.wg.color return color.a end,
						set = function(_, a) local color = E.db.epa.wg.color color.a = a or 1 end,
							--func = function() GridStatus:ResetClassColors() end,
						},			
			wg_threshold = {
						order = getOrder(),
						type = "range",
						name = "Overheal Threshold",
						desc = "Show WG when less than this % of overheal will occur. 100 will show the icon all the time, pending other settings!",
						softMax = 100,
						min = 0,
						step = 1,
						width = "full",
						get = function () return E.db.epa.wg.threshold end,
						set = function (_, v) E.db.epa.wg.threshold = v end,
			},
			wg_enable_if_have = {
						order = getOrder(),
						type = "toggle",
						name = "Show only while having the talent",
						desc = "Enable this if you want to hide this status while using a talent spec that does not include Wild Groth",
						width = "full",
						get = function () return E.db.epa.wg.enable_if_have end,
						set = function (_, v) E.db.epa.wg.enable_if_have = v; EPA:UpdateTalents(); end,
			},
			wg_hidecd = {
						order = getOrder(),
						type = "toggle",
						name = "Hide while on cooldown",
						desc = "Hide status while Wild Growth is on cooldown",
						width = "full",
						get = function () return E.db.epa.wg.hidecd end,
						set = function (_, arg) E.db.epa.wg.hidecd = arg end,
			},
			iconoptions = {
				order = getOrder(),
				type = 'group',
				name = 'WG Icon Options',
				guiInline = true,
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['wg'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['wg'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
			},
		}
	}
	E.Options.args.unitframe.args['raid'].args.priestaoe = {
				order = getOrder(),
				type = 'group',
				name = 'ElvUI Priest AoE',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe'][ info[#info] ] = value; UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {	
				},
	}
	
	E.Options.args.unitframe.args['raid'].args.priestaoe.args.poh = {
				order = getOrder(),
				type = 'group',
				name = 'PoH Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['poh'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['poh'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,
						},
					},
	}
	
	E.Options.args.unitframe.args['raid'].args.priestaoe.args.coh = {
				order = getOrder(),
				type = 'group',
				name = 'CoH Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['coh'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['coh'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
	}

	E.Options.args.unitframe.args['raid'].args.priestaoe.args.ch = {
				order = getOrder(),
				type = 'group',
				name = 'CH Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['ch'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['ch'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},
				},
	}

	E.Options.args.unitframe.args['raid'].args.priestaoe.args.hr = {
				order = getOrder(),
				type = 'group',
				name = 'HR Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['hr'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['hr'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
	}
	
	E.Options.args.unitframe.args['raid'].args.priestaoe.args.wg = {
				order = getOrder(),
				type = 'group',
				name = 'WG Icon Options',
				get = function(info) return E.db.unitframe.units['raid']['priestaoe']['wg'][ info[#info] ] end,
				set = function(info, value) E.db.unitframe.units['raid']['priestaoe']['wg'][ info[#info] ] = value; EPA:ApplyIconOptions(); UF:CreateAndUpdateHeaderGroup('raid') end,
				args = {
					enable = {
						type = 'toggle',
						order = getOrder(),
						name = 'Enable',
					},	
					attachTo = {
						type = 'select',
						order = getOrder(),
						name = 'Position',
						values = auraAnchors,
					},
					size = {
						type = 'range',
						name = 'Size',
						order = getOrder(),
						min = 8, max = 30, step = 1,
					},				
					xOffset = {
						order = getOrder(),
						type = 'range',
						name = 'xOffset',
						min = -50, max = 50, step = 1,
					},
					yOffset = {
						order = getOrder(),
						type = 'range',
						name = 'yOffset',
						min = -50, max = 50, step = 1,
					},	
					test = {
						order = getOrder(),
						type = 'toggle',
						name = 'Test Mode',
						get = function () return E.db.epa.debug.testmode end,
						set = function (_, v) E.db.epa.debug.testmode = v; EPA:ToggleTestMode(v) end,	
					},		
				},
	}
end

table.insert(E.EPAConfigs, configTable)